@@ -26,6 +26,98 @@ class CdwdorisClient(AbstractClient):
     _service = 'cdwdoris'
 
 
+    def CancelBackupJob(self, request):
+        """取消对应的备份实例任务
+
+        :param request: Request instance for CancelBackupJob.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.CancelBackupJobRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.CancelBackupJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CancelBackupJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.CancelBackupJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CheckCoolDownWorkingVariableConfigCorrect(self, request):
+        """查询冷热分层生效变量和配置是否正确
+
+        :param request: Request instance for CheckCoolDownWorkingVariableConfigCorrect.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.CheckCoolDownWorkingVariableConfigCorrectRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.CheckCoolDownWorkingVariableConfigCorrectResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckCoolDownWorkingVariableConfigCorrect", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckCoolDownWorkingVariableConfigCorrectResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateBackUpSchedule(self, request):
+        """创建或者修改备份策略
+
+        :param request: Request instance for CreateBackUpSchedule.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.CreateBackUpScheduleRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.CreateBackUpScheduleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateBackUpSchedule", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateBackUpScheduleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateCoolDownPolicy(self, request):
+        """创建冷热分层策略
+
+        :param request: Request instance for CreateCoolDownPolicy.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.CreateCoolDownPolicyRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.CreateCoolDownPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCoolDownPolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCoolDownPolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateInstanceNew(self, request):
         """通过API创建集群
 
@@ -72,6 +164,29 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteBackUpData(self, request):
+        """删除备份数据
+
+        :param request: Request instance for DeleteBackUpData.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DeleteBackUpDataRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DeleteBackUpDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteBackUpData", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteBackUpDataResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteWorkloadGroup(self, request):
         """删除资源组
 
@@ -95,6 +210,144 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAreaRegion(self, request):
+        """集群列表页上显示地域信息及各个地域的集群总数
+
+        :param request: Request instance for DescribeAreaRegion.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeAreaRegionRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeAreaRegionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAreaRegion", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAreaRegionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBackUpJob(self, request):
+        """查询备份实例列表
+
+        :param request: Request instance for DescribeBackUpJob.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpJobRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackUpJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackUpJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBackUpJobDetail(self, request):
+        """查询备份任务详情
+
+        :param request: Request instance for DescribeBackUpJobDetail.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpJobDetailRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpJobDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackUpJobDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackUpJobDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBackUpSchedules(self, request):
+        """获取备份、迁移的调度任务信息
+
+        :param request: Request instance for DescribeBackUpSchedules.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpSchedulesRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpSchedulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackUpSchedules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackUpSchedulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBackUpTables(self, request):
+        """获取可备份表信息
+
+        :param request: Request instance for DescribeBackUpTables.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpTablesRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpTablesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackUpTables", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackUpTablesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeBackUpTaskDetail(self, request):
+        """查询备份任务进度详情
+
+        :param request: Request instance for DescribeBackUpTaskDetail.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpTaskDetailRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeBackUpTaskDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBackUpTaskDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBackUpTaskDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeClusterConfigs(self, request):
         """获取集群的最新的几个配置文件（config.xml、metrika.xml、user.xml）的内容，显示给用户
 
@@ -118,6 +371,98 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeClusterConfigsHistory(self, request):
+        """获取集群配置文件修改历史
+
+        :param request: Request instance for DescribeClusterConfigsHistory.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeClusterConfigsHistoryRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeClusterConfigsHistoryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeClusterConfigsHistory", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeClusterConfigsHistoryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeCoolDownBackends(self, request):
+        """查询冷热分层backend节点信息列表
+
+        :param request: Request instance for DescribeCoolDownBackends.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeCoolDownBackendsRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeCoolDownBackendsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCoolDownBackends", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCoolDownBackendsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeCoolDownPolicies(self, request):
+        """查询冷热分层策略列表
+
+        :param request: Request instance for DescribeCoolDownPolicies.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeCoolDownPoliciesRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeCoolDownPoliciesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCoolDownPolicies", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCoolDownPoliciesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeCoolDownTableData(self, request):
+        """查询冷热分层Table数据
+
+        :param request: Request instance for DescribeCoolDownTableData.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeCoolDownTableDataRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeCoolDownTableDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeCoolDownTableData", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeCoolDownTableDataResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDatabaseAuditDownload(self, request):
         """下载数据库审计日志
 
@@ -164,52 +509,6 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeFederationToken(self, request):
-        """获取联合身份临时访问凭证
-
-        :param request: Request instance for DescribeFederationToken.
-        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeFederationTokenRequest`
-        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeFederationTokenResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeFederationToken", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeFederationTokenResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
-    def DescribeGoodsDetail(self, request):
-        """生成计费相关接口的GoodsDetail结构
-
-        :param request: Request instance for DescribeGoodsDetail.
-        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeGoodsDetailRequest`
-        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeGoodsDetailResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeGoodsDetail", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeGoodsDetailResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeInstance(self, request):
         """根据集群ID查询某个集群的具体信息
 
@@ -279,6 +578,52 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstanceNodesRole(self, request):
+        """获取集群节点角色
+
+        :param request: Request instance for DescribeInstanceNodesRole.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeInstanceNodesRoleRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeInstanceNodesRoleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstanceNodesRole", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstanceNodesRoleResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeInstanceOperations(self, request):
+        """在集群详情页面，拉取该集群的操作
+
+        :param request: Request instance for DescribeInstanceOperations.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeInstanceOperationsRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeInstanceOperationsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstanceOperations", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstanceOperationsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeInstanceState(self, request):
         """集群详情页中显示集群状态、流程进度等
 
@@ -348,43 +693,20 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeRegionZone(self, request):
-        """购买页获取地域及可用区列表、内核版本、网络规则等
+    def DescribeInstancesHealthState(self, request):
+        """集群健康检查
 
-        :param request: Request instance for DescribeRegionZone.
-        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeRegionZoneRequest`
-        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeRegionZoneResponse`
+        :param request: Request instance for DescribeInstancesHealthState.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeInstancesHealthStateRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeInstancesHealthStateResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("DescribeRegionZone", params, headers=headers)
+            body = self.call("DescribeInstancesHealthState", params, headers=headers)
             response = json.loads(body)
-            model = models.DescribeRegionZoneResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
-    def DescribeReplicaVersion(self, request):
-        """检查内核版本是否支持新的备份恢复语法
-
-        :param request: Request instance for DescribeReplicaVersion.
-        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeReplicaVersionRequest`
-        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeReplicaVersionResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeReplicaVersion", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeReplicaVersionResponse()
+            model = models.DescribeInstancesHealthStateResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
@@ -463,6 +785,29 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSpec(self, request):
+        """购买页拉取集群的数据节点和zookeeper节点的规格列表
+
+        :param request: Request instance for DescribeSpec.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeSpecRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeSpecResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSpec", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSpecResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeSqlApis(self, request):
         """针对驱动sql命令查询ck集群接口
 
@@ -486,6 +831,29 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeTableList(self, request):
+        """获取指定数据源和库下的表列表
+
+        :param request: Request instance for DescribeTableList.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeTableListRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.DescribeTableListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTableList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeTableListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeUserBindWorkloadGroup(self, request):
         """获取当前集群各用户绑定的资源信息
 
@@ -555,20 +923,20 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def FitClsLog(self, request):
-        """给已存在集群，配置日志服务
+    def ModifyCoolDownPolicy(self, request):
+        """修改冷热分层策略
 
-        :param request: Request instance for FitClsLog.
-        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.FitClsLogRequest`
-        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.FitClsLogResponse`
+        :param request: Request instance for ModifyCoolDownPolicy.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.ModifyCoolDownPolicyRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.ModifyCoolDownPolicyResponse`
 
         """
         try:
             params = request._serialize()
             headers = request.headers
-            body = self.call("FitClsLog", params, headers=headers)
+            body = self.call("ModifyCoolDownPolicy", params, headers=headers)
             response = json.loads(body)
-            model = models.FitClsLogResponse()
+            model = models.ModifyCoolDownPolicyResponse()
             model._deserialize(response["Response"])
             return model
         except Exception as e:
@@ -624,6 +992,29 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyNodeStatus(self, request):
+        """修改节点状态
+
+        :param request: Request instance for ModifyNodeStatus.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.ModifyNodeStatusRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.ModifyNodeStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyNodeStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyNodeStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifySecurityGroups(self, request):
         """更改安全组
 
@@ -739,6 +1130,75 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def OpenCoolDown(self, request):
+        """开始启用冷热分层
+
+        :param request: Request instance for OpenCoolDown.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.OpenCoolDownRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.OpenCoolDownResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("OpenCoolDown", params, headers=headers)
+            response = json.loads(body)
+            model = models.OpenCoolDownResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def OpenCoolDownPolicy(self, request):
+        """开通、描述降冷策略接口
+
+        :param request: Request instance for OpenCoolDownPolicy.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.OpenCoolDownPolicyRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.OpenCoolDownPolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("OpenCoolDownPolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.OpenCoolDownPolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def RecoverBackUpJob(self, request):
+        """备份恢复
+
+        :param request: Request instance for RecoverBackUpJob.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.RecoverBackUpJobRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.RecoverBackUpJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RecoverBackUpJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.RecoverBackUpJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ReduceInstance(self, request):
         """集群缩容
 
@@ -785,6 +1245,29 @@ class CdwdorisClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestartClusterForConfigs(self, request):
+        """重启集群让配置文件生效
+
+        :param request: Request instance for RestartClusterForConfigs.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.RestartClusterForConfigsRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.RestartClusterForConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestartClusterForConfigs", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestartClusterForConfigsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RestartClusterForNode(self, request):
         """集群滚动重启
 
@@ -847,6 +1330,29 @@ class CdwdorisClient(AbstractClient):
             model = models.ScaleUpInstanceResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateCoolDown(self, request):
+        """更新集群冷热分层信息
+
+        :param request: Request instance for UpdateCoolDown.
+        :type request: :class:`tencentcloud.cdwdoris.v20211228.models.UpdateCoolDownRequest`
+        :rtype: :class:`tencentcloud.cdwdoris.v20211228.models.UpdateCoolDownResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateCoolDown", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateCoolDownResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
