@@ -65,7 +65,7 @@ lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（
         :type DocumentType: str
         :param _SourceType: 数据来源，0：url，1：直接传文件编码后数据
         :type SourceType: int
-        :param _Url: 需要翻译文件url，文件限制如下：docx/xIsx/html/markdown文件不超过800万字符，doc/pdf/pptx文件不超过300页，txt/po文件不超过10MB，pdf/docx/pptx/xlsx不超过40MB
+        :param _Url: 需要翻译文件url，长度不超过256字符。文件限制如下：docx/xIsx/html/markdown文件不超过800万字符，doc/pdf/pptx文件不超过300页，txt/po文件不超过10MB，pdf/docx/pptx/xlsx不超过40MB
         :type Url: str
         :param _BasicDocumentType: 原始文档类型。该参数为高级参数，请留空，如需使用，请与工作人员确认后再使用。
         :type BasicDocumentType: str
@@ -410,7 +410,7 @@ class ImageTranslateRequest(AbstractModel):
         :type SessionUuid: str
         :param _Scene: doc:文档扫描
         :type Scene: str
-        :param _Data: 图片数据的Base64字符串，图片大小上限为4M，建议对源图片进行一定程度压缩
+        :param _Data: 图片数据的Base64字符串，经Base64编码后不超过 7M，分辨率建议600*800以上，支持PNG、JPG、JPEG、BMP、PDF格式。图片中包含文字需要少于6000字符。
         :type Data: str
         :param _Source: 源语言，支持语言列表：<li> auto：自动识别（识别为一种语言）</li> <li>zh：简体中文</li> <li>zh-TW：繁体中文</li> <li>en：英语</li> <li>ja：日语</li> <li>ko：韩语</li> <li>ru：俄语</li> <li>fr：法语</li> <li>de：德语</li> <li>it：意大利语</li> <li>es：西班牙语</li> <li>pt：葡萄牙语</li> <li>ms：马来西亚语</li> <li>th：泰语</li><li>vi：越南语</li>
         :type Source: str
